@@ -3,6 +3,7 @@ import os
 
 from notetool.secret import read_secret
 from sqlalchemy import MetaData, Table, create_engine
+from sqlalchemy.dialects.mysql import insert
 from sqlalchemy.orm import declarative_base
 
 uri = read_secret(cate1='notecoin', cate2='dataset', cate3='db_path')
@@ -17,7 +18,7 @@ logging.info(f'uri:{uri}')
 class BaseTable:
     def __init__(self, table_name, *args, **kwargs):
         self.table_name = table_name
-        self.table: Table
+        self.table: Table = None
         meta.create_all(engine)
 
     def insert(self, values, keys=None, *args, **kwargs):
@@ -30,7 +31,8 @@ class BaseTable:
                 values = [dict([(k, v) for k, v in item.items() if k in cols]) for item in values]
             elif isinstance(values[0], list):
                 values = [dict(zip(keys, item)) for item in values]
-        # ins = self.table.insert(values=values).prefix_with("OR REPLACE")
-        ins = self.table.insert(values=values)
-        ins = ins.on_duplicate_key_update(data=ins.inserted.data, status='U')
-        engine.execute(ins)
+        insert_stmt = insert(self.table).values(values)
+        self.on_duplicate_key_update(insert_stmt)
+
+    def on_duplicate_key_update(self, insert_stmt):
+        return engine.execute(insert_stmt.on_duplicate_key_update(symbol=insert_stmt.inserted.symbol))
