@@ -15,12 +15,10 @@ class LoadDataKline:
         super(LoadDataKline, self).__init__(*args, **kwargs)
 
     def load_all(self):
-        logging.info('Loading', self.exchange.id, 'markets...')
         self.exchange.load_markets()
-        for sym in self.exchange.symbols:
+        for sym in tqdm(self.exchange.symbols):
             if ':' not in sym:
-                print(sym)
-        logging.info('Loaded', self.exchange.id, 'markets.')
+                self.load(sym)
 
     def load(self, symbol, timeframe='1m', max_retries=3):
         limit = 100
